
using namespace System.Management.Automation
using namespace System.Management.Automation.Language

Register-ArgumentCompleter -Native -CommandName 'sq' -ScriptBlock {
    param($wordToComplete, $commandAst, $cursorPosition)

    $commandElements = $commandAst.CommandElements
    $command = @(
        'sq'
        for ($i = 1; $i -lt $commandElements.Count; $i++) {
            $element = $commandElements[$i]
            if ($element -isnot [StringConstantExpressionAst] -or
                $element.StringConstantType -ne [StringConstantType]::BareWord -or
                $element.Value.StartsWith('-') -or
                $element.Value -eq $wordToComplete) {
                break
        }
        $element.Value
    }) -join ';'

    $completions = @(switch ($command) {
        'sq' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('encrypt', 'encrypt', [CompletionResultType]::ParameterValue, 'Encrypt a message')
            [CompletionResult]::new('decrypt', 'decrypt', [CompletionResultType]::ParameterValue, 'Decrypt a message')
            [CompletionResult]::new('sign', 'sign', [CompletionResultType]::ParameterValue, 'Sign messages or data files')
            [CompletionResult]::new('verify', 'verify', [CompletionResultType]::ParameterValue, 'Verify signed messages or detached signatures')
            [CompletionResult]::new('inspect', 'inspect', [CompletionResultType]::ParameterValue, 'Inspect data, like file(1)')
            [CompletionResult]::new('cert', 'cert', [CompletionResultType]::ParameterValue, 'Manage certificates')
            [CompletionResult]::new('key', 'key', [CompletionResultType]::ParameterValue, 'Manage keys')
            [CompletionResult]::new('pki', 'pki', [CompletionResultType]::ParameterValue, 'Authenticate certs using the Web of Trust')
            [CompletionResult]::new('autocrypt', 'autocrypt', [CompletionResultType]::ParameterValue, 'Communicate certificates using Autocrypt')
            [CompletionResult]::new('network', 'network', [CompletionResultType]::ParameterValue, 'Retrieve and publish certificates over the network')
            [CompletionResult]::new('toolbox', 'toolbox', [CompletionResultType]::ParameterValue, 'Tools for developers, maintainers, and forensic specialists')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Detailed version and output version information')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;encrypt' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--recipient-email', 'recipient-email', [CompletionResultType]::ParameterName, 'Encrypt to all certificates that can be authenticated for the specified email address')
            [CompletionResult]::new('--recipient-userid', 'recipient-userid', [CompletionResultType]::ParameterName, 'Encrypt to all certificates that can be authenticated for the specified User ID')
            [CompletionResult]::new('--recipient-cert', 'recipient-cert', [CompletionResultType]::ParameterName, 'Encrypt to the named certificates')
            [CompletionResult]::new('--recipient-file', 'recipient-file', [CompletionResultType]::ParameterName, 'Encrypt to all certificates in CERT_RING_FILE')
            [CompletionResult]::new('--set-metadata-time', 'set-metadata-time', [CompletionResultType]::ParameterName, 'Set time for encrypted file as metadata')
            [CompletionResult]::new('--signer-file', 'signer-file', [CompletionResultType]::ParameterName, 'Sign the message using the key in KEY_FILE')
            [CompletionResult]::new('--signer-key', 'signer-key', [CompletionResultType]::ParameterName, 'Sign the message using the specified key on the key store')
            [CompletionResult]::new('--private-key-store', 'private-key-store', [CompletionResultType]::ParameterName, 'Provide parameters for private key store')
            [CompletionResult]::new('--encrypt-for', 'encrypt-for', [CompletionResultType]::ParameterName, 'Select what kind of keys are considered for encryption.')
            [CompletionResult]::new('--compression', 'compression', [CompletionResultType]::ParameterName, 'Select compression scheme to use')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--set-metadata-filename', 'set-metadata-filename', [CompletionResultType]::ParameterName, 'Set the filename of the encrypted file as metadata')
            [CompletionResult]::new('-s', 's', [CompletionResultType]::ParameterName, 'Prompt to add a password to encrypt with')
            [CompletionResult]::new('--symmetric', 'symmetric', [CompletionResultType]::ParameterName, 'Prompt to add a password to encrypt with')
            [CompletionResult]::new('--use-expired-subkey', 'use-expired-subkey', [CompletionResultType]::ParameterName, 'Fall back to expired encryption subkeys')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;decrypt' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('-n', 'n', [CompletionResultType]::ParameterName, 'Set the threshold of valid signatures to N')
            [CompletionResult]::new('--signatures', 'signatures', [CompletionResultType]::ParameterName, 'Set the threshold of valid signatures to N')
            [CompletionResult]::new('--signer-file', 'signer-file', [CompletionResultType]::ParameterName, 'Verify signatures using the certificates in CERT_FILE')
            [CompletionResult]::new('--recipient-file', 'recipient-file', [CompletionResultType]::ParameterName, 'Decrypt the message using the key in KEY_FILE')
            [CompletionResult]::new('--private-key-store', 'private-key-store', [CompletionResultType]::ParameterName, 'Provide parameters for private key store')
            [CompletionResult]::new('--session-key', 'session-key', [CompletionResultType]::ParameterName, 'Decrypt an encrypted message using SESSION-KEY')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--dump-session-key', 'dump-session-key', [CompletionResultType]::ParameterName, 'Print the session key to stderr')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;sign' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--private-key-store', 'private-key-store', [CompletionResultType]::ParameterName, 'Provide parameters for private key store')
            [CompletionResult]::new('--merge', 'merge', [CompletionResultType]::ParameterName, 'Merge signatures from the input and SIGNED-MESSAGE')
            [CompletionResult]::new('--signer-file', 'signer-file', [CompletionResultType]::ParameterName, 'Sign the message using the key in KEY_FILE')
            [CompletionResult]::new('--signer-key', 'signer-key', [CompletionResultType]::ParameterName, 'Sign the message using the specified key on the key store')
            [CompletionResult]::new('--notation', 'notation', [CompletionResultType]::ParameterName, 'Add a notation to the certification.')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--detached', 'detached', [CompletionResultType]::ParameterName, 'Create a detached signature')
            [CompletionResult]::new('--cleartext-signature', 'cleartext-signature', [CompletionResultType]::ParameterName, 'Create a cleartext signature')
            [CompletionResult]::new('-a', 'a', [CompletionResultType]::ParameterName, 'Append a signature to existing signature')
            [CompletionResult]::new('--append', 'append', [CompletionResultType]::ParameterName, 'Append a signature to existing signature')
            [CompletionResult]::new('-n', 'n', [CompletionResultType]::ParameterName, 'Sign a message and all existing signatures')
            [CompletionResult]::new('--notarize', 'notarize', [CompletionResultType]::ParameterName, 'Sign a message and all existing signatures')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;verify' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--detached', 'detached', [CompletionResultType]::ParameterName, 'Verify a detached signature')
            [CompletionResult]::new('-n', 'n', [CompletionResultType]::ParameterName, 'Set the threshold of valid signatures to N')
            [CompletionResult]::new('--signatures', 'signatures', [CompletionResultType]::ParameterName, 'Set the threshold of valid signatures to N')
            [CompletionResult]::new('--signer-file', 'signer-file', [CompletionResultType]::ParameterName, 'Verify signatures using the certificate in CERT_FILE')
            [CompletionResult]::new('--signer-cert', 'signer-cert', [CompletionResultType]::ParameterName, 'Verify signatures using the specified certificate')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;inspect' {
            [CompletionResult]::new('--cert', 'cert', [CompletionResultType]::ParameterName, 'Read the specified certificate from the certificate store')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--certifications', 'certifications', [CompletionResultType]::ParameterName, 'Print third-party certifications')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;cert' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import certificates into the local certificate store')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export certificates from the local certificate store')
            [CompletionResult]::new('lint', 'lint', [CompletionResultType]::ParameterValue, 'Check certificates for issues')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;cert;import' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;cert;export' {
            [CompletionResult]::new('--cert', 'cert', [CompletionResultType]::ParameterName, 'Return certificates that have the specified fingerprint or key ID')
            [CompletionResult]::new('--key', 'key', [CompletionResultType]::ParameterName, 'Return certificates where the primary key or a subkey has the specified fingerprint or key ID')
            [CompletionResult]::new('--userid', 'userid', [CompletionResultType]::ParameterName, 'Return certificates that have a User ID that matches exactly, including case')
            [CompletionResult]::new('--grep', 'grep', [CompletionResultType]::ParameterName, 'Return certificates that have a User ID that contains the string, case insensitively')
            [CompletionResult]::new('--email', 'email', [CompletionResultType]::ParameterName, 'Return certificates that have a User ID with the specified email address, case insensitively')
            [CompletionResult]::new('--domain', 'domain', [CompletionResultType]::ParameterName, 'Return certificates that have a User ID with an email address from the specified domain')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--all', 'all', [CompletionResultType]::ParameterName, 'Export all certificates')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;cert;lint' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-q', 'q', [CompletionResultType]::ParameterName, 'Quiet; does not output any diagnostics')
            [CompletionResult]::new('--quiet', 'quiet', [CompletionResultType]::ParameterName, 'Quiet; does not output any diagnostics')
            [CompletionResult]::new('-F', 'F ', [CompletionResultType]::ParameterName, 'Attempts to fix certificates, when possible')
            [CompletionResult]::new('--fix', 'fix', [CompletionResultType]::ParameterName, 'Attempts to fix certificates, when possible')
            [CompletionResult]::new('-e', 'e', [CompletionResultType]::ParameterName, 'When fixing a certificate, the fixed certificate is exported without any secret key material.  Using this switch causes any secret key material to also be exported')
            [CompletionResult]::new('--export-secret-keys', 'export-secret-keys', [CompletionResultType]::ParameterName, 'When fixing a certificate, the fixed certificate is exported without any secret key material.  Using this switch causes any secret key material to also be exported')
            [CompletionResult]::new('-k', 'k', [CompletionResultType]::ParameterName, 'If set, outputs a list of fingerprints, one per line, of certificates that have issues.  This output is intended for use by scripts')
            [CompletionResult]::new('--list-keys', 'list-keys', [CompletionResultType]::ParameterName, 'If set, outputs a list of fingerprints, one per line, of certificates that have issues.  This output is intended for use by scripts')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;cert;help' {
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import certificates into the local certificate store')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export certificates from the local certificate store')
            [CompletionResult]::new('lint', 'lint', [CompletionResultType]::ParameterValue, 'Check certificates for issues')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;cert;help;import' {
            break
        }
        'sq;cert;help;export' {
            break
        }
        'sq;cert;help;lint' {
            break
        }
        'sq;cert;help;help' {
            break
        }
        'sq;key' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys managed by the key store')
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate a new key')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import keys into the key store')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export keys from the key store')
            [CompletionResult]::new('password', 'password', [CompletionResultType]::ParameterValue, 'Change password protecting secrets')
            [CompletionResult]::new('expire', 'expire', [CompletionResultType]::ParameterValue, 'Change expiration times')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a certificate')
            [CompletionResult]::new('userid', 'userid', [CompletionResultType]::ParameterValue, 'Manage User IDs')
            [CompletionResult]::new('subkey', 'subkey', [CompletionResultType]::ParameterValue, 'Manage Subkeys')
            [CompletionResult]::new('attest-certifications', 'attest-certifications', [CompletionResultType]::ParameterValue, 'Attest to third-party certifications')
            [CompletionResult]::new('adopt', 'adopt', [CompletionResultType]::ParameterValue, 'Bind keys from one certificate to another')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;key;list' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;generate' {
            [CompletionResult]::new('-u', 'u', [CompletionResultType]::ParameterName, 'Add a user ID to the key')
            [CompletionResult]::new('--userid', 'userid', [CompletionResultType]::ParameterName, 'Add a user ID to the key')
            [CompletionResult]::new('-c', 'c', [CompletionResultType]::ParameterName, 'Select the cryptographic algorithms for the key')
            [CompletionResult]::new('--cipher-suite', 'cipher-suite', [CompletionResultType]::ParameterName, 'Select the cryptographic algorithms for the key')
            [CompletionResult]::new('--expiry', 'expiry', [CompletionResultType]::ParameterName, 'Define EXPIRY for the key as ISO 8601 formatted string or custom duration.')
            [CompletionResult]::new('--can-encrypt', 'can-encrypt', [CompletionResultType]::ParameterName, 'Add an encryption-capable subkey [default: universal]')
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--rev-cert', 'rev-cert', [CompletionResultType]::ParameterName, 'Write the revocation certificate to FILE')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--allow-non-canonical-userids', 'allow-non-canonical-userids', [CompletionResultType]::ParameterName, 'Don''t reject user IDs that are not in canonical form')
            [CompletionResult]::new('--no-userids', 'no-userids', [CompletionResultType]::ParameterName, 'Create a key without any user IDs')
            [CompletionResult]::new('--with-password', 'with-password', [CompletionResultType]::ParameterName, 'Protect the key with a password')
            [CompletionResult]::new('--can-sign', 'can-sign', [CompletionResultType]::ParameterName, 'Add a signing-capable subkey (default)')
            [CompletionResult]::new('--cannot-sign', 'cannot-sign', [CompletionResultType]::ParameterName, 'Add no signing-capable subkey')
            [CompletionResult]::new('--can-authenticate', 'can-authenticate', [CompletionResultType]::ParameterName, 'Add an authentication-capable subkey (default)')
            [CompletionResult]::new('--cannot-authenticate', 'cannot-authenticate', [CompletionResultType]::ParameterName, 'Add no authentication-capable subkey')
            [CompletionResult]::new('--cannot-encrypt', 'cannot-encrypt', [CompletionResultType]::ParameterName, 'Add no encryption-capable subkey')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;import' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;export' {
            [CompletionResult]::new('--cert', 'cert', [CompletionResultType]::ParameterName, 'Export the specified certificate')
            [CompletionResult]::new('--key', 'key', [CompletionResultType]::ParameterName, 'Export the specified key')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;password' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--old-password-file', 'old-password-file', [CompletionResultType]::ParameterName, 'File containing password to decrypt key')
            [CompletionResult]::new('--new-password-file', 'new-password-file', [CompletionResultType]::ParameterName, 'File containing password to encrypt key')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--clear', 'clear', [CompletionResultType]::ParameterName, 'Emit a key with unencrypted secrets')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;expire' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--subkey', 'subkey', [CompletionResultType]::ParameterName, 'Change expiration of this subkey, not the entire key')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;revoke' {
            [CompletionResult]::new('--certificate-file', 'certificate-file', [CompletionResultType]::ParameterName, 'The certificate to revoke')
            [CompletionResult]::new('--revocation-file', 'revocation-file', [CompletionResultType]::ParameterName, 'Sign the revocation certificate using the key in KEY_FILE')
            [CompletionResult]::new('--private-key-store', 'private-key-store', [CompletionResultType]::ParameterName, 'Provide parameters for private key store')
            [CompletionResult]::new('--notation', 'notation', [CompletionResultType]::ParameterName, 'Add a notation to the certification.')
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;userid' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a User ID')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a User ID')
            [CompletionResult]::new('strip', 'strip', [CompletionResultType]::ParameterValue, 'Strip a User ID')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;key;userid;add' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--private-key-store', 'private-key-store', [CompletionResultType]::ParameterName, 'Provide parameters for private key store')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--allow-non-canonical-userids', 'allow-non-canonical-userids', [CompletionResultType]::ParameterName, 'Don''t reject user IDs that are not in canonical form')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;userid;revoke' {
            [CompletionResult]::new('--certificate-file', 'certificate-file', [CompletionResultType]::ParameterName, 'The certificate containing the User ID to revoke')
            [CompletionResult]::new('--revocation-file', 'revocation-file', [CompletionResultType]::ParameterName, 'Sign the revocation certificate using the key in KEY_FILE')
            [CompletionResult]::new('--private-key-store', 'private-key-store', [CompletionResultType]::ParameterName, 'Provide parameters for private key store')
            [CompletionResult]::new('--notation', 'notation', [CompletionResultType]::ParameterName, 'Add a notation to the certification.')
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;userid;strip' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('-u', 'u', [CompletionResultType]::ParameterName, 'User IDs to strip')
            [CompletionResult]::new('--userid', 'userid', [CompletionResultType]::ParameterName, 'User IDs to strip')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;userid;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a User ID')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a User ID')
            [CompletionResult]::new('strip', 'strip', [CompletionResultType]::ParameterValue, 'Strip a User ID')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;key;userid;help;add' {
            break
        }
        'sq;key;userid;help;revoke' {
            break
        }
        'sq;key;userid;help;strip' {
            break
        }
        'sq;key;userid;help;help' {
            break
        }
        'sq;key;subkey' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a newly generated Subkey')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a subkey')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;key;subkey;add' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--private-key-store', 'private-key-store', [CompletionResultType]::ParameterName, 'Provide parameters for private key store')
            [CompletionResult]::new('-c', 'c', [CompletionResultType]::ParameterName, 'Select the cryptographic algorithms for the subkey')
            [CompletionResult]::new('--cipher-suite', 'cipher-suite', [CompletionResultType]::ParameterName, 'Select the cryptographic algorithms for the subkey')
            [CompletionResult]::new('--expiry', 'expiry', [CompletionResultType]::ParameterName, 'Define EXPIRY for the subkey as ISO 8601 formatted string or custom duration.')
            [CompletionResult]::new('--can-encrypt', 'can-encrypt', [CompletionResultType]::ParameterName, 'Add an encryption capability to subkey [default: universal]')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--can-sign', 'can-sign', [CompletionResultType]::ParameterName, 'Add signing capability to subkey')
            [CompletionResult]::new('--can-authenticate', 'can-authenticate', [CompletionResultType]::ParameterName, 'Add authentication capability to subkey')
            [CompletionResult]::new('--with-password', 'with-password', [CompletionResultType]::ParameterName, 'Protect the subkey with a password')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;subkey;revoke' {
            [CompletionResult]::new('--certificate-file', 'certificate-file', [CompletionResultType]::ParameterName, 'The certificate containing the subkey to revoke')
            [CompletionResult]::new('--revocation-file', 'revocation-file', [CompletionResultType]::ParameterName, 'Sign the revocation certificate using the key in KEY_FILE')
            [CompletionResult]::new('--private-key-store', 'private-key-store', [CompletionResultType]::ParameterName, 'Provide parameters for private key store')
            [CompletionResult]::new('--notation', 'notation', [CompletionResultType]::ParameterName, 'Add a notation to the certification.')
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;subkey;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a newly generated Subkey')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a subkey')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;key;subkey;help;add' {
            break
        }
        'sq;key;subkey;help;revoke' {
            break
        }
        'sq;key;subkey;help;help' {
            break
        }
        'sq;key;attest-certifications' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--none', 'none', [CompletionResultType]::ParameterName, 'Remove all prior attestations')
            [CompletionResult]::new('--all', 'all', [CompletionResultType]::ParameterName, 'Attest to all certifications [default]')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;adopt' {
            [CompletionResult]::new('-k', 'k', [CompletionResultType]::ParameterName, 'Add the key or subkey KEY to the TARGET-KEY')
            [CompletionResult]::new('--key', 'key', [CompletionResultType]::ParameterName, 'Add the key or subkey KEY to the TARGET-KEY')
            [CompletionResult]::new('--expire', 'expire', [CompletionResultType]::ParameterName, 'Make adopted subkeys expire at the given time')
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--allow-broken-crypto', 'allow-broken-crypto', [CompletionResultType]::ParameterName, 'Allow adopting keys from certificates using broken cryptography')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;key;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys managed by the key store')
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate a new key')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import keys into the key store')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export keys from the key store')
            [CompletionResult]::new('password', 'password', [CompletionResultType]::ParameterValue, 'Change password protecting secrets')
            [CompletionResult]::new('expire', 'expire', [CompletionResultType]::ParameterValue, 'Change expiration times')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a certificate')
            [CompletionResult]::new('userid', 'userid', [CompletionResultType]::ParameterValue, 'Manage User IDs')
            [CompletionResult]::new('subkey', 'subkey', [CompletionResultType]::ParameterValue, 'Manage Subkeys')
            [CompletionResult]::new('attest-certifications', 'attest-certifications', [CompletionResultType]::ParameterValue, 'Attest to third-party certifications')
            [CompletionResult]::new('adopt', 'adopt', [CompletionResultType]::ParameterValue, 'Bind keys from one certificate to another')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;key;help;list' {
            break
        }
        'sq;key;help;generate' {
            break
        }
        'sq;key;help;import' {
            break
        }
        'sq;key;help;export' {
            break
        }
        'sq;key;help;password' {
            break
        }
        'sq;key;help;expire' {
            break
        }
        'sq;key;help;revoke' {
            break
        }
        'sq;key;help;userid' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a User ID')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a User ID')
            [CompletionResult]::new('strip', 'strip', [CompletionResultType]::ParameterValue, 'Strip a User ID')
            break
        }
        'sq;key;help;userid;add' {
            break
        }
        'sq;key;help;userid;revoke' {
            break
        }
        'sq;key;help;userid;strip' {
            break
        }
        'sq;key;help;subkey' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a newly generated Subkey')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a subkey')
            break
        }
        'sq;key;help;subkey;add' {
            break
        }
        'sq;key;help;subkey;revoke' {
            break
        }
        'sq;key;help;attest-certifications' {
            break
        }
        'sq;key;help;adopt' {
            break
        }
        'sq;key;help;help' {
            break
        }
        'sq;pki' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('authenticate', 'authenticate', [CompletionResultType]::ParameterValue, 'Authenticate a binding')
            [CompletionResult]::new('lookup', 'lookup', [CompletionResultType]::ParameterValue, 'Lookup the certificates associated with a User ID')
            [CompletionResult]::new('identify', 'identify', [CompletionResultType]::ParameterValue, 'Identify a certificate')
            [CompletionResult]::new('certify', 'certify', [CompletionResultType]::ParameterValue, 'Certify a User ID for a Certificate')
            [CompletionResult]::new('link', 'link', [CompletionResultType]::ParameterValue, 'Manage authenticated certificate and User ID links')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List all authenticated bindings (User ID and certificate pairs)')
            [CompletionResult]::new('path', 'path', [CompletionResultType]::ParameterValue, 'Verify the specified path')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;pki;authenticate' {
            [CompletionResult]::new('-a', 'a', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--amount', 'amount', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--show-paths', 'show-paths', [CompletionResultType]::ParameterName, 'Show why a binding is authenticated')
            [CompletionResult]::new('--email', 'email', [CompletionResultType]::ParameterName, 'Changes the USERID parameter to match User IDs with the specified email address')
            [CompletionResult]::new('--gossip', 'gossip', [CompletionResultType]::ParameterName, 'Treats all certificates as unreliable trust roots')
            [CompletionResult]::new('--certification-network', 'certification-network', [CompletionResultType]::ParameterName, 'Treats the network as a certification network')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;lookup' {
            [CompletionResult]::new('-a', 'a', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--amount', 'amount', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--show-paths', 'show-paths', [CompletionResultType]::ParameterName, 'Show why a binding is authenticated')
            [CompletionResult]::new('--email', 'email', [CompletionResultType]::ParameterName, 'Changes the USERID parameter to match User IDs with the specified email address')
            [CompletionResult]::new('--gossip', 'gossip', [CompletionResultType]::ParameterName, 'Treats all certificates as unreliable trust roots')
            [CompletionResult]::new('--certification-network', 'certification-network', [CompletionResultType]::ParameterName, 'Treats the network as a certification network')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;identify' {
            [CompletionResult]::new('-a', 'a', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--amount', 'amount', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--show-paths', 'show-paths', [CompletionResultType]::ParameterName, 'Show why a binding is authenticated')
            [CompletionResult]::new('--gossip', 'gossip', [CompletionResultType]::ParameterName, 'Treats all certificates as unreliable trust roots')
            [CompletionResult]::new('--certification-network', 'certification-network', [CompletionResultType]::ParameterName, 'Treats the network as a certification network')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;certify' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('-d', 'd', [CompletionResultType]::ParameterName, 'Set the trust depth')
            [CompletionResult]::new('--depth', 'depth', [CompletionResultType]::ParameterName, 'Set the trust depth')
            [CompletionResult]::new('-a', 'a', [CompletionResultType]::ParameterName, 'Set the amount of trust')
            [CompletionResult]::new('--amount', 'amount', [CompletionResultType]::ParameterName, 'Set the amount of trust')
            [CompletionResult]::new('-r', 'r', [CompletionResultType]::ParameterName, 'Add a regular expression to constrain what a trusted introducer can certify')
            [CompletionResult]::new('--regex', 'regex', [CompletionResultType]::ParameterName, 'Add a regular expression to constrain what a trusted introducer can certify')
            [CompletionResult]::new('--notation', 'notation', [CompletionResultType]::ParameterName, 'Add a notation to the certification.')
            [CompletionResult]::new('--expiry', 'expiry', [CompletionResultType]::ParameterName, 'Define EXPIRY for the certification as ISO 8601 formatted string or custom duration.')
            [CompletionResult]::new('--private-key-store', 'private-key-store', [CompletionResultType]::ParameterName, 'Provide parameters for private key store')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-l', 'l', [CompletionResultType]::ParameterName, 'Make the certification a local certification')
            [CompletionResult]::new('--local', 'local', [CompletionResultType]::ParameterName, 'Make the certification a local certification')
            [CompletionResult]::new('--non-revocable', 'non-revocable', [CompletionResultType]::ParameterName, 'Mark the certification as being non-revocable')
            [CompletionResult]::new('--email', 'email', [CompletionResultType]::ParameterName, 'Treat the given user ID as an email address.')
            [CompletionResult]::new('--add-userid', 'add-userid', [CompletionResultType]::ParameterName, 'Add the given user ID if it doesn''t exist.')
            [CompletionResult]::new('--allow-not-alive-certifier', 'allow-not-alive-certifier', [CompletionResultType]::ParameterName, 'Don''t fail if the certificate making the certification is not alive.')
            [CompletionResult]::new('--allow-revoked-certifier', 'allow-revoked-certifier', [CompletionResultType]::ParameterName, 'Don''t fail if the certificate making the certification is revoked.')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;link' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Link a certificate and a User ID')
            [CompletionResult]::new('retract', 'retract', [CompletionResultType]::ParameterValue, 'Retract links')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List links')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;pki;link;add' {
            [CompletionResult]::new('-d', 'd', [CompletionResultType]::ParameterName, 'Set the trust depth')
            [CompletionResult]::new('--depth', 'depth', [CompletionResultType]::ParameterName, 'Set the trust depth')
            [CompletionResult]::new('--ca', 'ca', [CompletionResultType]::ParameterName, 'Mark the certificate as a certification authority for a domain')
            [CompletionResult]::new('-a', 'a', [CompletionResultType]::ParameterName, 'Set the amount of trust')
            [CompletionResult]::new('--amount', 'amount', [CompletionResultType]::ParameterName, 'Set the amount of trust')
            [CompletionResult]::new('-r', 'r', [CompletionResultType]::ParameterName, 'Add a regular expression to constrain what a trusted introducer can certify')
            [CompletionResult]::new('--regex', 'regex', [CompletionResultType]::ParameterName, 'Add a regular expression to constrain what a trusted introducer can certify')
            [CompletionResult]::new('--notation', 'notation', [CompletionResultType]::ParameterName, 'Add a notation to the certification.')
            [CompletionResult]::new('--expiry', 'expiry', [CompletionResultType]::ParameterName, 'Define EXPIRY for the acceptance as ISO 8601 formatted string or custom duration.')
            [CompletionResult]::new('--userid', 'userid', [CompletionResultType]::ParameterName, 'A User ID to link to the certificate.')
            [CompletionResult]::new('--email', 'email', [CompletionResultType]::ParameterName, 'An email address to link to the certificate.')
            [CompletionResult]::new('--petname', 'petname', [CompletionResultType]::ParameterName, 'A User ID to link to the certificate.')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--temporary', 'temporary', [CompletionResultType]::ParameterName, 'Temporarily accepts the binding')
            [CompletionResult]::new('--all', 'all', [CompletionResultType]::ParameterName, 'Link all valid self-signed User ID to the certificate.')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;link;retract' {
            [CompletionResult]::new('--notation', 'notation', [CompletionResultType]::ParameterName, 'Add a notation to the certification.')
            [CompletionResult]::new('--userid', 'userid', [CompletionResultType]::ParameterName, 'A User ID to unlink from the certificate.')
            [CompletionResult]::new('--email', 'email', [CompletionResultType]::ParameterName, 'An email address to unlink from the certificate.')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;link;list' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--ca', 'ca', [CompletionResultType]::ParameterName, 'Only lists bindings linked as CAs.')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;link;help' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Link a certificate and a User ID')
            [CompletionResult]::new('retract', 'retract', [CompletionResultType]::ParameterValue, 'Retract links')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List links')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;pki;link;help;add' {
            break
        }
        'sq;pki;link;help;retract' {
            break
        }
        'sq;pki;link;help;list' {
            break
        }
        'sq;pki;link;help;help' {
            break
        }
        'sq;pki;list' {
            [CompletionResult]::new('-a', 'a', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--amount', 'amount', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--show-paths', 'show-paths', [CompletionResultType]::ParameterName, 'Show why a binding is authenticated')
            [CompletionResult]::new('--email', 'email', [CompletionResultType]::ParameterName, 'Changes the USERID parameter to match User IDs with the specified email address')
            [CompletionResult]::new('--gossip', 'gossip', [CompletionResultType]::ParameterName, 'Treats all certificates as unreliable trust roots')
            [CompletionResult]::new('--certification-network', 'certification-network', [CompletionResultType]::ParameterName, 'Treats the network as a certification network')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;path' {
            [CompletionResult]::new('-a', 'a', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--amount', 'amount', [CompletionResultType]::ParameterName, 'The required amount of trust')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--gossip', 'gossip', [CompletionResultType]::ParameterName, 'Treats all certificates as unreliable trust roots')
            [CompletionResult]::new('--certification-network', 'certification-network', [CompletionResultType]::ParameterName, 'Treats the network as a certification network')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;pki;help' {
            [CompletionResult]::new('authenticate', 'authenticate', [CompletionResultType]::ParameterValue, 'Authenticate a binding')
            [CompletionResult]::new('lookup', 'lookup', [CompletionResultType]::ParameterValue, 'Lookup the certificates associated with a User ID')
            [CompletionResult]::new('identify', 'identify', [CompletionResultType]::ParameterValue, 'Identify a certificate')
            [CompletionResult]::new('certify', 'certify', [CompletionResultType]::ParameterValue, 'Certify a User ID for a Certificate')
            [CompletionResult]::new('link', 'link', [CompletionResultType]::ParameterValue, 'Manage authenticated certificate and User ID links')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List all authenticated bindings (User ID and certificate pairs)')
            [CompletionResult]::new('path', 'path', [CompletionResultType]::ParameterValue, 'Verify the specified path')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;pki;help;authenticate' {
            break
        }
        'sq;pki;help;lookup' {
            break
        }
        'sq;pki;help;identify' {
            break
        }
        'sq;pki;help;certify' {
            break
        }
        'sq;pki;help;link' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Link a certificate and a User ID')
            [CompletionResult]::new('retract', 'retract', [CompletionResultType]::ParameterValue, 'Retract links')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List links')
            break
        }
        'sq;pki;help;link;add' {
            break
        }
        'sq;pki;help;link;retract' {
            break
        }
        'sq;pki;help;link;list' {
            break
        }
        'sq;pki;help;list' {
            break
        }
        'sq;pki;help;path' {
            break
        }
        'sq;pki;help;help' {
            break
        }
        'sq;autocrypt' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import Autocrypt-encoded certificates')
            [CompletionResult]::new('decode', 'decode', [CompletionResultType]::ParameterValue, 'Read Autocrypt-encoded certificates')
            [CompletionResult]::new('encode-sender', 'encode-sender', [CompletionResultType]::ParameterValue, 'Encode a certificate into an Autocrypt header')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;autocrypt;import' {
            [CompletionResult]::new('--recipient-file', 'recipient-file', [CompletionResultType]::ParameterName, 'Decrypt the message using the key in KEY_FILE')
            [CompletionResult]::new('--session-key', 'session-key', [CompletionResultType]::ParameterName, 'Decrypt an encrypted message using SESSION-KEY')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;autocrypt;decode' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;autocrypt;encode-sender' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--email', 'email', [CompletionResultType]::ParameterName, 'Set the address [default: primary userid]')
            [CompletionResult]::new('--prefer-encrypt', 'prefer-encrypt', [CompletionResultType]::ParameterName, 'Set the prefer-encrypt attribute')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;autocrypt;help' {
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import Autocrypt-encoded certificates')
            [CompletionResult]::new('decode', 'decode', [CompletionResultType]::ParameterValue, 'Read Autocrypt-encoded certificates')
            [CompletionResult]::new('encode-sender', 'encode-sender', [CompletionResultType]::ParameterValue, 'Encode a certificate into an Autocrypt header')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;autocrypt;help;import' {
            break
        }
        'sq;autocrypt;help;decode' {
            break
        }
        'sq;autocrypt;help;encode-sender' {
            break
        }
        'sq;autocrypt;help;help' {
            break
        }
        'sq;network' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates using all supported network services')
            [CompletionResult]::new('keyserver', 'keyserver', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via key servers')
            [CompletionResult]::new('wkd', 'wkd', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via Web Key Directories')
            [CompletionResult]::new('dane', 'dane', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via DANE')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;network;fetch' {
            [CompletionResult]::new('-s', 's', [CompletionResultType]::ParameterName, 'Set the key server to use.  Can be given multiple times.')
            [CompletionResult]::new('--server', 'server', [CompletionResultType]::ParameterName, 'Set the key server to use.  Can be given multiple times.')
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--all', 'all', [CompletionResultType]::ParameterName, 'Fetch updates for all known certificates')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;keyserver' {
            [CompletionResult]::new('-s', 's', [CompletionResultType]::ParameterName, 'Set the key server to use.  Can be given multiple times.')
            [CompletionResult]::new('--server', 'server', [CompletionResultType]::ParameterName, 'Set the key server to use.  Can be given multiple times.')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates from key servers')
            [CompletionResult]::new('publish', 'publish', [CompletionResultType]::ParameterValue, 'Publish certificates on key servers')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;network;keyserver;fetch' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('-s', 's', [CompletionResultType]::ParameterName, 'Set the key server to use.  Can be given multiple times.')
            [CompletionResult]::new('--server', 'server', [CompletionResultType]::ParameterName, 'Set the key server to use.  Can be given multiple times.')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--all', 'all', [CompletionResultType]::ParameterName, 'Fetch updates for all known certificates')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;keyserver;publish' {
            [CompletionResult]::new('-s', 's', [CompletionResultType]::ParameterName, 'Set the key server to use.  Can be given multiple times.')
            [CompletionResult]::new('--server', 'server', [CompletionResultType]::ParameterName, 'Set the key server to use.  Can be given multiple times.')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--require-all', 'require-all', [CompletionResultType]::ParameterName, 'Require that all publish operations succeed and return an error otherwise.  By default we only require that one publish operation succeeds.')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;keyserver;help' {
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates from key servers')
            [CompletionResult]::new('publish', 'publish', [CompletionResultType]::ParameterValue, 'Publish certificates on key servers')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;network;keyserver;help;fetch' {
            break
        }
        'sq;network;keyserver;help;publish' {
            break
        }
        'sq;network;keyserver;help;help' {
            break
        }
        'sq;network;wkd' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate a Web Key Directory for the given domain and certs')
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates from a Web Key Directory')
            [CompletionResult]::new('direct-url', 'direct-url', [CompletionResultType]::ParameterValue, 'Print the direct Web Key Directory URL of an email address')
            [CompletionResult]::new('url', 'url', [CompletionResultType]::ParameterValue, 'Print the advanced Web Key Directory URL of an email address')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;network;wkd;generate' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-d', 'd', [CompletionResultType]::ParameterName, 'Use the direct method [default: advanced method]')
            [CompletionResult]::new('--direct-method', 'direct-method', [CompletionResultType]::ParameterName, 'Use the direct method [default: advanced method]')
            [CompletionResult]::new('-s', 's', [CompletionResultType]::ParameterName, 'Skip certificates that do not have User IDs for given domain.')
            [CompletionResult]::new('--skip', 'skip', [CompletionResultType]::ParameterName, 'Skip certificates that do not have User IDs for given domain.')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;wkd;fetch' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--all', 'all', [CompletionResultType]::ParameterName, 'Fetch updates for all known certificates')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;wkd;direct-url' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;wkd;url' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;wkd;help' {
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate a Web Key Directory for the given domain and certs')
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates from a Web Key Directory')
            [CompletionResult]::new('direct-url', 'direct-url', [CompletionResultType]::ParameterValue, 'Print the direct Web Key Directory URL of an email address')
            [CompletionResult]::new('url', 'url', [CompletionResultType]::ParameterValue, 'Print the advanced Web Key Directory URL of an email address')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;network;wkd;help;generate' {
            break
        }
        'sq;network;wkd;help;fetch' {
            break
        }
        'sq;network;wkd;help;direct-url' {
            break
        }
        'sq;network;wkd;help;url' {
            break
        }
        'sq;network;wkd;help;help' {
            break
        }
        'sq;network;dane' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate DANE records for the given domain and certs')
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates using DANE')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;network;dane;generate' {
            [CompletionResult]::new('--ttl', 'ttl', [CompletionResultType]::ParameterName, 'Set the TTL (maximum cache duration) of the resource records')
            [CompletionResult]::new('--size-limit', 'size-limit', [CompletionResultType]::ParameterName, 'Try to shrink the certificates to this size')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--generic', 'generic', [CompletionResultType]::ParameterName, 'Emit generic resource records [default: OPENPGPKEY records]')
            [CompletionResult]::new('-s', 's', [CompletionResultType]::ParameterName, 'Skip expired certificates and those that do not have User IDs for given domain.')
            [CompletionResult]::new('--skip', 'skip', [CompletionResultType]::ParameterName, 'Skip expired certificates and those that do not have User IDs for given domain.')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;dane;fetch' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE (or stdout when omitted) instead of importing into the certificate store')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--all', 'all', [CompletionResultType]::ParameterName, 'Fetch updates for all known certificates')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;network;dane;help' {
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate DANE records for the given domain and certs')
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates using DANE')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;network;dane;help;generate' {
            break
        }
        'sq;network;dane;help;fetch' {
            break
        }
        'sq;network;dane;help;help' {
            break
        }
        'sq;network;help' {
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates using all supported network services')
            [CompletionResult]::new('keyserver', 'keyserver', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via key servers')
            [CompletionResult]::new('wkd', 'wkd', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via Web Key Directories')
            [CompletionResult]::new('dane', 'dane', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via DANE')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;network;help;fetch' {
            break
        }
        'sq;network;help;keyserver' {
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates from key servers')
            [CompletionResult]::new('publish', 'publish', [CompletionResultType]::ParameterValue, 'Publish certificates on key servers')
            break
        }
        'sq;network;help;keyserver;fetch' {
            break
        }
        'sq;network;help;keyserver;publish' {
            break
        }
        'sq;network;help;wkd' {
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate a Web Key Directory for the given domain and certs')
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates from a Web Key Directory')
            [CompletionResult]::new('direct-url', 'direct-url', [CompletionResultType]::ParameterValue, 'Print the direct Web Key Directory URL of an email address')
            [CompletionResult]::new('url', 'url', [CompletionResultType]::ParameterValue, 'Print the advanced Web Key Directory URL of an email address')
            break
        }
        'sq;network;help;wkd;generate' {
            break
        }
        'sq;network;help;wkd;fetch' {
            break
        }
        'sq;network;help;wkd;direct-url' {
            break
        }
        'sq;network;help;wkd;url' {
            break
        }
        'sq;network;help;dane' {
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate DANE records for the given domain and certs')
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates using DANE')
            break
        }
        'sq;network;help;dane;generate' {
            break
        }
        'sq;network;help;dane;fetch' {
            break
        }
        'sq;network;help;help' {
            break
        }
        'sq;toolbox' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('keyring', 'keyring', [CompletionResultType]::ParameterValue, 'Manage collections of keys or certs')
            [CompletionResult]::new('extract-cert', 'extract-cert', [CompletionResultType]::ParameterValue, 'Convert a key to a cert')
            [CompletionResult]::new('packet', 'packet', [CompletionResultType]::ParameterValue, 'Low-level packet manipulation')
            [CompletionResult]::new('armor', 'armor', [CompletionResultType]::ParameterValue, 'Convert binary to ASCII')
            [CompletionResult]::new('dearmor', 'dearmor', [CompletionResultType]::ParameterValue, 'Convert ASCII to binary')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;toolbox;keyring' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys in a keyring')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a keyring into individual keys')
            [CompletionResult]::new('merge', 'merge', [CompletionResultType]::ParameterValue, 'Merge keys or keyrings into a single keyring')
            [CompletionResult]::new('filter', 'filter', [CompletionResultType]::ParameterValue, 'Join keys into a keyring applying a filter')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;toolbox;keyring;list' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--all-userids', 'all-userids', [CompletionResultType]::ParameterName, 'List all user ids')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;keyring;split' {
            [CompletionResult]::new('-p', 'p', [CompletionResultType]::ParameterName, 'Write to files with PREFIX [defaults: `FILE-` if FILE is set, or `output-` if read from stdin]')
            [CompletionResult]::new('--prefix', 'prefix', [CompletionResultType]::ParameterName, 'Write to files with PREFIX [defaults: `FILE-` if FILE is set, or `output-` if read from stdin]')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;keyring;merge' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;keyring;filter' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--userid', 'userid', [CompletionResultType]::ParameterName, 'Match on USERID')
            [CompletionResult]::new('--name', 'name', [CompletionResultType]::ParameterName, 'Match on NAME')
            [CompletionResult]::new('--email', 'email', [CompletionResultType]::ParameterName, 'Match on email ADDRESS')
            [CompletionResult]::new('--domain', 'domain', [CompletionResultType]::ParameterName, 'Match on email domain FQDN')
            [CompletionResult]::new('--handle', 'handle', [CompletionResultType]::ParameterName, 'Match on (sub)key fingerprints and key ids')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-P', 'P ', [CompletionResultType]::ParameterName, 'Remove certificate components not matching the filter')
            [CompletionResult]::new('--prune-certs', 'prune-certs', [CompletionResultType]::ParameterName, 'Remove certificate components not matching the filter')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--to-cert', 'to-cert', [CompletionResultType]::ParameterName, 'Convert any keys in the input to certificates.  Converting a key to a certificate removes secret key material from the key thereby turning it into a certificate.')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;keyring;help' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys in a keyring')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a keyring into individual keys')
            [CompletionResult]::new('merge', 'merge', [CompletionResultType]::ParameterValue, 'Merge keys or keyrings into a single keyring')
            [CompletionResult]::new('filter', 'filter', [CompletionResultType]::ParameterValue, 'Join keys into a keyring applying a filter')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;toolbox;keyring;help;list' {
            break
        }
        'sq;toolbox;keyring;help;split' {
            break
        }
        'sq;toolbox;keyring;help;merge' {
            break
        }
        'sq;toolbox;keyring;help;filter' {
            break
        }
        'sq;toolbox;keyring;help;help' {
            break
        }
        'sq;toolbox;extract-cert' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;packet' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('dump', 'dump', [CompletionResultType]::ParameterValue, 'List packets')
            [CompletionResult]::new('decrypt', 'decrypt', [CompletionResultType]::ParameterValue, 'Unwrap an encryption container')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a message into packets')
            [CompletionResult]::new('join', 'join', [CompletionResultType]::ParameterValue, 'Join packets split across files')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;toolbox;packet;dump' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--session-key', 'session-key', [CompletionResultType]::ParameterName, 'Decrypt an encrypted message using SESSION-KEY')
            [CompletionResult]::new('--recipient-file', 'recipient-file', [CompletionResultType]::ParameterName, 'Decrypt the message using the key in KEY_FILE')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--mpis', 'mpis', [CompletionResultType]::ParameterName, 'Print cryptographic artifacts')
            [CompletionResult]::new('-x', 'x', [CompletionResultType]::ParameterName, 'Print a hexdump')
            [CompletionResult]::new('--hex', 'hex', [CompletionResultType]::ParameterName, 'Print a hexdump')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;packet;decrypt' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--recipient-file', 'recipient-file', [CompletionResultType]::ParameterName, 'Decrypt the message using the key in KEY_FILE')
            [CompletionResult]::new('--private-key-store', 'private-key-store', [CompletionResultType]::ParameterName, 'Provide parameters for private key store')
            [CompletionResult]::new('--session-key', 'session-key', [CompletionResultType]::ParameterName, 'Decrypt an encrypted message using SESSION-KEY')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--dump-session-key', 'dump-session-key', [CompletionResultType]::ParameterName, 'Print the session key to stderr')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;packet;split' {
            [CompletionResult]::new('-p', 'p', [CompletionResultType]::ParameterName, 'Write to files with PREFIX [defaults: `FILE-` if FILE is set, or `output-` if read from stdin]')
            [CompletionResult]::new('--prefix', 'prefix', [CompletionResultType]::ParameterName, 'Write to files with PREFIX [defaults: `FILE-` if FILE is set, or `output-` if read from stdin]')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;packet;join' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--label', 'label', [CompletionResultType]::ParameterName, 'Select the kind of armor header')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-B', 'B ', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('--binary', 'binary', [CompletionResultType]::ParameterName, 'Emit binary data')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;packet;help' {
            [CompletionResult]::new('dump', 'dump', [CompletionResultType]::ParameterValue, 'List packets')
            [CompletionResult]::new('decrypt', 'decrypt', [CompletionResultType]::ParameterValue, 'Unwrap an encryption container')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a message into packets')
            [CompletionResult]::new('join', 'join', [CompletionResultType]::ParameterValue, 'Join packets split across files')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;toolbox;packet;help;dump' {
            break
        }
        'sq;toolbox;packet;help;decrypt' {
            break
        }
        'sq;toolbox;packet;help;split' {
            break
        }
        'sq;toolbox;packet;help;join' {
            break
        }
        'sq;toolbox;packet;help;help' {
            break
        }
        'sq;toolbox;armor' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--label', 'label', [CompletionResultType]::ParameterName, 'Select the kind of armor header')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;dearmor' {
            [CompletionResult]::new('-o', 'o', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--output', 'output', [CompletionResultType]::ParameterName, 'Write to FILE or stdout if omitted')
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;toolbox;help' {
            [CompletionResult]::new('keyring', 'keyring', [CompletionResultType]::ParameterValue, 'Manage collections of keys or certs')
            [CompletionResult]::new('extract-cert', 'extract-cert', [CompletionResultType]::ParameterValue, 'Convert a key to a cert')
            [CompletionResult]::new('packet', 'packet', [CompletionResultType]::ParameterValue, 'Low-level packet manipulation')
            [CompletionResult]::new('armor', 'armor', [CompletionResultType]::ParameterValue, 'Convert binary to ASCII')
            [CompletionResult]::new('dearmor', 'dearmor', [CompletionResultType]::ParameterValue, 'Convert ASCII to binary')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;toolbox;help;keyring' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys in a keyring')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a keyring into individual keys')
            [CompletionResult]::new('merge', 'merge', [CompletionResultType]::ParameterValue, 'Merge keys or keyrings into a single keyring')
            [CompletionResult]::new('filter', 'filter', [CompletionResultType]::ParameterValue, 'Join keys into a keyring applying a filter')
            break
        }
        'sq;toolbox;help;keyring;list' {
            break
        }
        'sq;toolbox;help;keyring;split' {
            break
        }
        'sq;toolbox;help;keyring;merge' {
            break
        }
        'sq;toolbox;help;keyring;filter' {
            break
        }
        'sq;toolbox;help;extract-cert' {
            break
        }
        'sq;toolbox;help;packet' {
            [CompletionResult]::new('dump', 'dump', [CompletionResultType]::ParameterValue, 'List packets')
            [CompletionResult]::new('decrypt', 'decrypt', [CompletionResultType]::ParameterValue, 'Unwrap an encryption container')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a message into packets')
            [CompletionResult]::new('join', 'join', [CompletionResultType]::ParameterValue, 'Join packets split across files')
            break
        }
        'sq;toolbox;help;packet;dump' {
            break
        }
        'sq;toolbox;help;packet;decrypt' {
            break
        }
        'sq;toolbox;help;packet;split' {
            break
        }
        'sq;toolbox;help;packet;join' {
            break
        }
        'sq;toolbox;help;armor' {
            break
        }
        'sq;toolbox;help;dearmor' {
            break
        }
        'sq;toolbox;help;help' {
            break
        }
        'sq;version' {
            [CompletionResult]::new('--home', 'home', [CompletionResultType]::ParameterName, 'Set the home directory.')
            [CompletionResult]::new('--key-store', 'key-store', [CompletionResultType]::ParameterName, 'Override the key store server and its data')
            [CompletionResult]::new('--cert-store', 'cert-store', [CompletionResultType]::ParameterName, 'Specify the location of the certificate store')
            [CompletionResult]::new('--pep-cert-store', 'pep-cert-store', [CompletionResultType]::ParameterName, 'Specify the location of a pEp certificate store')
            [CompletionResult]::new('--keyring', 'keyring', [CompletionResultType]::ParameterName, 'Specify the location of a keyring to use')
            [CompletionResult]::new('--output-format', 'output-format', [CompletionResultType]::ParameterName, 'Produce output in FORMAT, if possible')
            [CompletionResult]::new('--output-version', 'output-version', [CompletionResultType]::ParameterName, 'Produce output variant VERSION.')
            [CompletionResult]::new('--known-notation', 'known-notation', [CompletionResultType]::ParameterName, 'Add NOTATION to the list of known notations')
            [CompletionResult]::new('--time', 'time', [CompletionResultType]::ParameterName, 'Set the reference time as ISO 8601 formatted timestamp')
            [CompletionResult]::new('--trust-root', 'trust-root', [CompletionResultType]::ParameterName, 'Consider the specified certificate to be a trust root')
            [CompletionResult]::new('--default-output-version', 'default-output-version', [CompletionResultType]::ParameterName, 'List the default output version')
            [CompletionResult]::new('--output-versions', 'output-versions', [CompletionResultType]::ParameterName, 'List all the supported output versions')
            [CompletionResult]::new('-f', 'f', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--force', 'force', [CompletionResultType]::ParameterName, 'Overwrite existing files')
            [CompletionResult]::new('--no-key-store', 'no-key-store', [CompletionResultType]::ParameterName, 'Disable the use of the key store.')
            [CompletionResult]::new('--no-cert-store', 'no-cert-store', [CompletionResultType]::ParameterName, 'Disable the use of a certificate store')
            [CompletionResult]::new('-v', 'v', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('--verbose', 'verbose', [CompletionResultType]::ParameterName, 'Be more verbose.')
            [CompletionResult]::new('-h', 'h', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            [CompletionResult]::new('--help', 'help', [CompletionResultType]::ParameterName, 'Print help (see more with ''--help'')')
            break
        }
        'sq;help' {
            [CompletionResult]::new('encrypt', 'encrypt', [CompletionResultType]::ParameterValue, 'Encrypt a message')
            [CompletionResult]::new('decrypt', 'decrypt', [CompletionResultType]::ParameterValue, 'Decrypt a message')
            [CompletionResult]::new('sign', 'sign', [CompletionResultType]::ParameterValue, 'Sign messages or data files')
            [CompletionResult]::new('verify', 'verify', [CompletionResultType]::ParameterValue, 'Verify signed messages or detached signatures')
            [CompletionResult]::new('inspect', 'inspect', [CompletionResultType]::ParameterValue, 'Inspect data, like file(1)')
            [CompletionResult]::new('cert', 'cert', [CompletionResultType]::ParameterValue, 'Manage certificates')
            [CompletionResult]::new('key', 'key', [CompletionResultType]::ParameterValue, 'Manage keys')
            [CompletionResult]::new('pki', 'pki', [CompletionResultType]::ParameterValue, 'Authenticate certs using the Web of Trust')
            [CompletionResult]::new('autocrypt', 'autocrypt', [CompletionResultType]::ParameterValue, 'Communicate certificates using Autocrypt')
            [CompletionResult]::new('network', 'network', [CompletionResultType]::ParameterValue, 'Retrieve and publish certificates over the network')
            [CompletionResult]::new('toolbox', 'toolbox', [CompletionResultType]::ParameterValue, 'Tools for developers, maintainers, and forensic specialists')
            [CompletionResult]::new('version', 'version', [CompletionResultType]::ParameterValue, 'Detailed version and output version information')
            [CompletionResult]::new('help', 'help', [CompletionResultType]::ParameterValue, 'Print this message or the help of the given subcommand(s)')
            break
        }
        'sq;help;encrypt' {
            break
        }
        'sq;help;decrypt' {
            break
        }
        'sq;help;sign' {
            break
        }
        'sq;help;verify' {
            break
        }
        'sq;help;inspect' {
            break
        }
        'sq;help;cert' {
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import certificates into the local certificate store')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export certificates from the local certificate store')
            [CompletionResult]::new('lint', 'lint', [CompletionResultType]::ParameterValue, 'Check certificates for issues')
            break
        }
        'sq;help;cert;import' {
            break
        }
        'sq;help;cert;export' {
            break
        }
        'sq;help;cert;lint' {
            break
        }
        'sq;help;key' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys managed by the key store')
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate a new key')
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import keys into the key store')
            [CompletionResult]::new('export', 'export', [CompletionResultType]::ParameterValue, 'Export keys from the key store')
            [CompletionResult]::new('password', 'password', [CompletionResultType]::ParameterValue, 'Change password protecting secrets')
            [CompletionResult]::new('expire', 'expire', [CompletionResultType]::ParameterValue, 'Change expiration times')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a certificate')
            [CompletionResult]::new('userid', 'userid', [CompletionResultType]::ParameterValue, 'Manage User IDs')
            [CompletionResult]::new('subkey', 'subkey', [CompletionResultType]::ParameterValue, 'Manage Subkeys')
            [CompletionResult]::new('attest-certifications', 'attest-certifications', [CompletionResultType]::ParameterValue, 'Attest to third-party certifications')
            [CompletionResult]::new('adopt', 'adopt', [CompletionResultType]::ParameterValue, 'Bind keys from one certificate to another')
            break
        }
        'sq;help;key;list' {
            break
        }
        'sq;help;key;generate' {
            break
        }
        'sq;help;key;import' {
            break
        }
        'sq;help;key;export' {
            break
        }
        'sq;help;key;password' {
            break
        }
        'sq;help;key;expire' {
            break
        }
        'sq;help;key;revoke' {
            break
        }
        'sq;help;key;userid' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a User ID')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a User ID')
            [CompletionResult]::new('strip', 'strip', [CompletionResultType]::ParameterValue, 'Strip a User ID')
            break
        }
        'sq;help;key;userid;add' {
            break
        }
        'sq;help;key;userid;revoke' {
            break
        }
        'sq;help;key;userid;strip' {
            break
        }
        'sq;help;key;subkey' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Add a newly generated Subkey')
            [CompletionResult]::new('revoke', 'revoke', [CompletionResultType]::ParameterValue, 'Revoke a subkey')
            break
        }
        'sq;help;key;subkey;add' {
            break
        }
        'sq;help;key;subkey;revoke' {
            break
        }
        'sq;help;key;attest-certifications' {
            break
        }
        'sq;help;key;adopt' {
            break
        }
        'sq;help;pki' {
            [CompletionResult]::new('authenticate', 'authenticate', [CompletionResultType]::ParameterValue, 'Authenticate a binding')
            [CompletionResult]::new('lookup', 'lookup', [CompletionResultType]::ParameterValue, 'Lookup the certificates associated with a User ID')
            [CompletionResult]::new('identify', 'identify', [CompletionResultType]::ParameterValue, 'Identify a certificate')
            [CompletionResult]::new('certify', 'certify', [CompletionResultType]::ParameterValue, 'Certify a User ID for a Certificate')
            [CompletionResult]::new('link', 'link', [CompletionResultType]::ParameterValue, 'Manage authenticated certificate and User ID links')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List all authenticated bindings (User ID and certificate pairs)')
            [CompletionResult]::new('path', 'path', [CompletionResultType]::ParameterValue, 'Verify the specified path')
            break
        }
        'sq;help;pki;authenticate' {
            break
        }
        'sq;help;pki;lookup' {
            break
        }
        'sq;help;pki;identify' {
            break
        }
        'sq;help;pki;certify' {
            break
        }
        'sq;help;pki;link' {
            [CompletionResult]::new('add', 'add', [CompletionResultType]::ParameterValue, 'Link a certificate and a User ID')
            [CompletionResult]::new('retract', 'retract', [CompletionResultType]::ParameterValue, 'Retract links')
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List links')
            break
        }
        'sq;help;pki;link;add' {
            break
        }
        'sq;help;pki;link;retract' {
            break
        }
        'sq;help;pki;link;list' {
            break
        }
        'sq;help;pki;list' {
            break
        }
        'sq;help;pki;path' {
            break
        }
        'sq;help;autocrypt' {
            [CompletionResult]::new('import', 'import', [CompletionResultType]::ParameterValue, 'Import Autocrypt-encoded certificates')
            [CompletionResult]::new('decode', 'decode', [CompletionResultType]::ParameterValue, 'Read Autocrypt-encoded certificates')
            [CompletionResult]::new('encode-sender', 'encode-sender', [CompletionResultType]::ParameterValue, 'Encode a certificate into an Autocrypt header')
            break
        }
        'sq;help;autocrypt;import' {
            break
        }
        'sq;help;autocrypt;decode' {
            break
        }
        'sq;help;autocrypt;encode-sender' {
            break
        }
        'sq;help;network' {
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates using all supported network services')
            [CompletionResult]::new('keyserver', 'keyserver', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via key servers')
            [CompletionResult]::new('wkd', 'wkd', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via Web Key Directories')
            [CompletionResult]::new('dane', 'dane', [CompletionResultType]::ParameterValue, 'Retrieve and publishes certificates via DANE')
            break
        }
        'sq;help;network;fetch' {
            break
        }
        'sq;help;network;keyserver' {
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates from key servers')
            [CompletionResult]::new('publish', 'publish', [CompletionResultType]::ParameterValue, 'Publish certificates on key servers')
            break
        }
        'sq;help;network;keyserver;fetch' {
            break
        }
        'sq;help;network;keyserver;publish' {
            break
        }
        'sq;help;network;wkd' {
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate a Web Key Directory for the given domain and certs')
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates from a Web Key Directory')
            [CompletionResult]::new('direct-url', 'direct-url', [CompletionResultType]::ParameterValue, 'Print the direct Web Key Directory URL of an email address')
            [CompletionResult]::new('url', 'url', [CompletionResultType]::ParameterValue, 'Print the advanced Web Key Directory URL of an email address')
            break
        }
        'sq;help;network;wkd;generate' {
            break
        }
        'sq;help;network;wkd;fetch' {
            break
        }
        'sq;help;network;wkd;direct-url' {
            break
        }
        'sq;help;network;wkd;url' {
            break
        }
        'sq;help;network;dane' {
            [CompletionResult]::new('generate', 'generate', [CompletionResultType]::ParameterValue, 'Generate DANE records for the given domain and certs')
            [CompletionResult]::new('fetch', 'fetch', [CompletionResultType]::ParameterValue, 'Retrieve certificates using DANE')
            break
        }
        'sq;help;network;dane;generate' {
            break
        }
        'sq;help;network;dane;fetch' {
            break
        }
        'sq;help;toolbox' {
            [CompletionResult]::new('keyring', 'keyring', [CompletionResultType]::ParameterValue, 'Manage collections of keys or certs')
            [CompletionResult]::new('extract-cert', 'extract-cert', [CompletionResultType]::ParameterValue, 'Convert a key to a cert')
            [CompletionResult]::new('packet', 'packet', [CompletionResultType]::ParameterValue, 'Low-level packet manipulation')
            [CompletionResult]::new('armor', 'armor', [CompletionResultType]::ParameterValue, 'Convert binary to ASCII')
            [CompletionResult]::new('dearmor', 'dearmor', [CompletionResultType]::ParameterValue, 'Convert ASCII to binary')
            break
        }
        'sq;help;toolbox;keyring' {
            [CompletionResult]::new('list', 'list', [CompletionResultType]::ParameterValue, 'List keys in a keyring')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a keyring into individual keys')
            [CompletionResult]::new('merge', 'merge', [CompletionResultType]::ParameterValue, 'Merge keys or keyrings into a single keyring')
            [CompletionResult]::new('filter', 'filter', [CompletionResultType]::ParameterValue, 'Join keys into a keyring applying a filter')
            break
        }
        'sq;help;toolbox;keyring;list' {
            break
        }
        'sq;help;toolbox;keyring;split' {
            break
        }
        'sq;help;toolbox;keyring;merge' {
            break
        }
        'sq;help;toolbox;keyring;filter' {
            break
        }
        'sq;help;toolbox;extract-cert' {
            break
        }
        'sq;help;toolbox;packet' {
            [CompletionResult]::new('dump', 'dump', [CompletionResultType]::ParameterValue, 'List packets')
            [CompletionResult]::new('decrypt', 'decrypt', [CompletionResultType]::ParameterValue, 'Unwrap an encryption container')
            [CompletionResult]::new('split', 'split', [CompletionResultType]::ParameterValue, 'Split a message into packets')
            [CompletionResult]::new('join', 'join', [CompletionResultType]::ParameterValue, 'Join packets split across files')
            break
        }
        'sq;help;toolbox;packet;dump' {
            break
        }
        'sq;help;toolbox;packet;decrypt' {
            break
        }
        'sq;help;toolbox;packet;split' {
            break
        }
        'sq;help;toolbox;packet;join' {
            break
        }
        'sq;help;toolbox;armor' {
            break
        }
        'sq;help;toolbox;dearmor' {
            break
        }
        'sq;help;version' {
            break
        }
        'sq;help;help' {
            break
        }
    })

    $completions.Where{ $_.CompletionText -like "$wordToComplete*" } |
        Sort-Object -Property ListItemText
}
